pub struct Polygon { /* private fields */ }Expand description
A polygon with a bounding box.
This struct implements From<geoo:Polygon>, so for GIS applications you can instantiate this
from any geo::Polygon.
Implementations
Sourceimpl Polygon
impl Polygon
Sourcepub fn new(bounds: [(f32, f32); 2], points: Vec<(f32, f32)>) -> Polygon
pub fn new(bounds: [(f32, f32); 2], points: Vec<(f32, f32)>) -> Polygon
Construct a Polygon from a bounding-box and set of points.
bounds should be [(min_x, max_x), (min_y, max_y)].
points should be an exterior ring concatenated with a (possibly empty) set of interior
rings, where a “ring” is a list of points where the first and last point are equal.
The exterior ring of points should be positively oriented, i.e. it should go in
counter-clockwise order. The interior rings should be negatively oriented.